==> gplus-0.23.00.tar.gz: gplus-0.23.00/gui/AboutDlg.h <==
//---------------------------------------------------------------------------
//
// Name:        AboutDlg.h
// Author:      Marcinello
// Created:     2006-12-05 00:38:26
// Description: AboutDlg class declaration
//
//---------------------------------------------------------------------------

#ifndef __ABOUTDLG_h__
#define __ABOUTDLG_h__

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#ifndef WX_PRECOMP
	#include <wx/wx.h>
	#include <wx/dialog.h>
#else
	#include <wx/wxprec.h>
#endif

//Do not add custom headers
//wxDev-C++ designer will remove them
////Header Include Start
#include <wx/statline.h>
#include <wx/button.h>
#include <wx/hyperlink.h>
#include <wx/stattext.h>
#include <wx/statbox.h>
////Header Include End

////Dialog Style Start
#undef AboutDlg_STYLE
#define AboutDlg_STYLE wxCAPTION | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxCLOSE_BOX
////Dialog Style End

class AboutDlg : public wxDialog
{
	private:
		DECLARE_EVENT_TABLE();
		
	public:
		AboutDlg(wxWindow *parent, wxWindowID id = 1, const wxString &title = wxT("About..."), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = AboutDlg_STYLE);
		virtual ~AboutDlg();
		void WxButton1Click(wxCommandEvent& event);
		void WxButton2Click(wxCommandEvent& event);
	
	private:
		//Do not add custom control declarations
		//wxDev-C++ will remove them. Add custom code after the block.
		////GUI Control Declaration Start
		wxHyperlinkCtrl *WxHyperLinkCtrl4;
		wxStaticText *WxStaticText16;
		wxStaticText *WxStaticText15;
		wxStaticText *WxStaticText14;
		wxStaticText *WxStaticText7;
		wxStaticBox *WxStaticBox4;
		wxStaticText *WxStaticText13;
		wxStaticText *WxStaticText10;
		wxHyperlinkCtrl *WxHyperLinkCtrl3;
		wxStaticText *WxStaticText5;
		wxStaticBox *WxStaticBox3;
		wxStaticLine *WxStaticLine2;
		wxStaticText *WxStaticText12;
		wxStaticText *WxStaticText11;
		wxStaticLine *WxStaticLine1;
		wxStaticText *WxStaticText6;
		wxStaticText *WxStaticText9;
		wxStaticText *WxStaticText8;
		wxHyperlinkCtrl *WxHyperLinkCtrl2;
		wxButton *WxButton1;
		wxHyperlinkCtrl *WxHyperLinkCtrl1;
		wxStaticText *WxStaticText4;
		wxStaticText *WxStaticText3;
		wxStaticText *WxStaticText2;
		wxStaticText *WxStaticText1;
		wxStaticBox *WxStaticBox2;
		wxStaticBox *WxStaticBox1;
		////GUI Control Declaration End
		
	private:
		//Note: if you receive any error with these enum IDs, then you need to
		//change your old form code that are based on the #define control IDs.
		//#defines may replace a numeric value for the enum names.
		//Try copy and pasting the below block in your old form header files.
		enum
		{
			////GUI Enum Control ID Start
			ID_WXHYPERLINKCTRL4 = 1037,
			ID_WXSTATICTEXT16 = 1036,
			ID_WXSTATICTEXT15 = 1035,
			ID_WXSTATICTEXT14 = 1034,
			ID_WXSTATICTEXT7 = 1033,
			ID_WXSTATICBOX4 = 1032,
			ID_WXSTATICTEXT13 = 1031,
			ID_WXSTATICTEXT10 = 1030,
			ID_WXHYPERLINKCTRL3 = 1028,
			ID_WXSTATICTEXT5 = 1027,
			ID_WXSTATICBOX3 = 1026,
			ID_WXSTATICLINE2 = 1025,
			ID_WXSTATICTEXT12 = 1024,
			ID_WXSTATICTEXT11 = 1023,
			ID_WXSTATICLINE1 = 1022,
			ID_WXSTATICTEXT6 = 1019,
			ID_WXSTATICTEXT9 = 1016,
			ID_WXSTATICTEXT8 = 1015,
			ID_WXHYPERLINKCTRL2 = 1014,
			ID_WXBUTTON1 = 1012,
			ID_WXHYPERLINKCTRL1 = 1009,
			ID_WXSTATICTEXT4 = 1008,
			ID_WXSTATICTEXT3 = 1007,
			ID_WXSTATICTEXT2 = 1006,
			ID_WXSTATICTEXT1 = 1005,
			ID_WXSTATICBOX2 = 1018,
			ID_WXSTATICBOX1 = 1004,
			////GUI Enum Control ID End
			ID_DUMMY_VALUE_ //don't remove this value unless you have other enum values
		};
	
	private:
		void OnClose(wxCloseEvent& event);
		void CreateGUIControls();
};

#endif

==> gplus-0.29.00.tar.gz: gplus-0.29.00/gui/AboutDlg.h <==
//---------------------------------------------------------------------------
//
// Name:        AboutDlg.h
// Author:      Marcinello
// Created:     2006-12-05 00:38:26
// Description: AboutDlg class declaration
//
//---------------------------------------------------------------------------

#ifndef __ABOUTDLG_h__
#define __ABOUTDLG_h__

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#ifndef WX_PRECOMP
	#include <wx/wx.h>
	#include <wx/dialog.h>
#else
	#include <wx/wxprec.h>
#endif

//Do not add custom headers
//wxDev-C++ designer will remove them
////Header Include Start
#include <wx/statline.h>
#include <wx/button.h>
#include <wx/hyperlink.h>
#include <wx/stattext.h>
#include <wx/statbox.h>
////Header Include End

////Dialog Style Start
#undef AboutDlg_STYLE
#define AboutDlg_STYLE wxCAPTION | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxCLOSE_BOX
////Dialog Style End

class AboutDlg : public wxDialog
{
	private:
		DECLARE_EVENT_TABLE();
		
	public:
		AboutDlg(wxWindow *parent, wxWindowID id = 1, const wxString &title = wxT("About..."), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = AboutDlg_STYLE);
		virtual ~AboutDlg();
		void WxButton1Click(wxCommandEvent& event);
		void WxButton2Click(wxCommandEvent& event);
	
	private:
		//Do not add custom control declarations
		//wxDev-C++ will remove them. Add custom code after the block.
		////GUI Control Declaration Start
		wxStaticText *WxStaticText19;
		wxStaticText *WxStaticText18;
		wxStaticText *WxStaticText17;
		wxHyperlinkCtrl *WxHyperLinkCtrl4;
		wxStaticText *WxStaticText16;
		wxStaticText *WxStaticText15;
		wxStaticText *WxStaticText14;
		wxStaticText *WxStaticText7;
		wxStaticBox *WxStaticBox4;
		wxStaticText *WxStaticText13;
		wxStaticText *WxStaticText10;
		wxHyperlinkCtrl *WxHyperLinkCtrl3;
		wxStaticText *WxStaticText5;
		wxStaticBox *WxStaticBox3;
		wxStaticLine *WxStaticLine2;
		wxStaticText *WxStaticText12;
		wxStaticText *WxStaticText11;
		wxStaticLine *WxStaticLine1;
		wxStaticText *WxStaticText6;
		wxStaticText *WxStaticText9;
		wxStaticText *WxStaticText8;
		wxHyperlinkCtrl *WxHyperLinkCtrl2;
		wxButton *WxButton1;
		wxHyperlinkCtrl *WxHyperLinkCtrl1;
		wxStaticText *WxStaticText4;
		wxStaticText *WxStaticText3;
		wxStaticText *WxStaticText2;
		wxStaticText *WxStaticText1;
		wxStaticBox *WxStaticBox2;
		wxStaticBox *WxStaticBox1;
		////GUI Control Declaration End
		
	private:
		//Note: if you receive any error with these enum IDs, then you need to
		//change your old form code that are based on the #define control IDs.
		//#defines may replace a numeric value for the enum names.
		//Try copy and pasting the below block in your old form header files.
		enum
		{
			////GUI Enum Control ID Start
			ID_WXSTATICTEXT19 = 1040,
			ID_WXSTATICTEXT18 = 1039,
			ID_WXSTATICTEXT17 = 1038,
			ID_WXHYPERLINKCTRL4 = 1037,
			ID_WXSTATICTEXT16 = 1036,
			ID_WXSTATICTEXT15 = 1035,
			ID_WXSTATICTEXT14 = 1034,
			ID_WXSTATICTEXT7 = 1033,
			ID_WXSTATICBOX4 = 1032,
			ID_WXSTATICTEXT13 = 1031,
			ID_WXSTATICTEXT10 = 1030,
			ID_WXHYPERLINKCTRL3 = 1028,
			ID_WXSTATICTEXT5 = 1027,
			ID_WXSTATICBOX3 = 1026,
			ID_WXSTATICLINE2 = 1025,
			ID_WXSTATICTEXT12 = 1024,
			ID_WXSTATICTEXT11 = 1023,
			ID_WXSTATICLINE1 = 1022,
			ID_WXSTATICTEXT6 = 1019,
			ID_WXSTATICTEXT9 = 1016,
			ID_WXSTATICTEXT8 = 1015,
			ID_WXHYPERLINKCTRL2 = 1014,
			ID_WXBUTTON1 = 1012,
			ID_WXHYPERLINKCTRL1 = 1009,
			ID_WXSTATICTEXT4 = 1008,
			ID_WXSTATICTEXT3 = 1007,
			ID_WXSTATICTEXT2 = 1006,
			ID_WXSTATICTEXT1 = 1005,
			ID_WXSTATICBOX2 = 1018,
			ID_WXSTATICBOX1 = 1004,
			////GUI Enum Control ID End
			ID_DUMMY_VALUE_ //don't remove this value unless you have other enum values
		};
	
	private:
		void OnClose(wxCloseEvent& event);
		void CreateGUIControls();
};

#endif
